
module("Action", package.seeall)

-- avoid memory leak
collectgarbage("setpause", 100)
collectgarbage("setstepmul", 5000)

local sharedScheduler = CCScheduler:sharedScheduler()

local stack = {}

local function push(_name, _handle, _args)
    table.insert(stack, {name = _name, handle = _handle, args = _args})
    return handle
end

local function unschedule(name)
	for i,v in pairs(stack) do
        if v.name == name then
			if v.handle ~= nil then
				sharedScheduler:unscheduleScriptEntry(v.handle)
			end
            table.remove(stack, i)
            return
        end
	end
end

local function unscheduleAll()
	for i,v in pairs(stack) do
		sharedScheduler:unscheduleScriptEntry(v.handle)
	end
    stack = {}
end

local function performWithDelay(name, time, listener, args)
    local handle = sharedScheduler:scheduleScriptFunc(function()
        listener()
    end, time, false)
	push(name, handle, args)
    return handle
end

function setTimer(name, time, func, args)
	if type(name) ~= "string" then
		return
	end
	
	for i,v in pairs(stack) do
        if v.name == name then
			return
		end
	end
	
	if type(time) ~= "number" then
		return
	end
	
	if func == nil or type(func) ~= "function" then
		return
	end

	performWithDelay(name, time, function()
		unschedule(name)
		func(args)
	end, args)
end

function invalidateTimer(name)
	for i,v in pairs(stack) do
        if v.name == name then
			unschedule(name)
			table.remove(stack, i)
            return
        end
	end
end
