
module("InteractionSystem", package.seeall)

-- avoid memory leak
collectgarbage("setpause", 100)
collectgarbage("setstepmul", 5000)

require("LevelSystem")

function init(funcs)
	local funcEvent = function(object, state)
		if object == nil then
			return
		end
		local func = funcs[state]
		if func ~= nil and type(func) == "function" then
			func(object)
		end
	end
	
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tiledMap = gameScreen:getTiledMap()
		if tiledMap ~= nil then
			local interactionManager = tiledMap:getInteractionManager()
			if interactionManager ~= nil then
				local name = interactionManager:getInteractionObjectName()
				if name ~= "" then
					local object = LevelSystem.getLevelObject(name)
					if object ~= nil then
						object:registerScriptHandler(funcEvent)
					end
				end
			end
		end
	end
end

--[[
value sample with default properties:
boo = {
	["start_point"] = {}, -- {{1,1},...}
	["script"] = "",
	["duration"] = 0.0,
	["times"] = 1,
	["character_animation"] = "",
	["animation"] = "",
	["animation_reverse"] = false,
	["animation_end"] = "",
	["animation_end_reverse"] = false,
	["sound"] = "",
	["sound_end"] = "",
	["sprite"] = "",
	["sprite_end"] = "",
	["interaction_end_sprite_removed"] = false,
	["requirement_character_type"] = "",
	["requirement_character_level"] = 0,
	["requirement_item"] = 0,
	["cost"] = 0
}
]]--

function get(value)
	local interaction = Interaction:create()
	
	if value["start_point"] ~= nil and type(value["start_point"]) == "table" then
		interaction.mStartPointCount = 0
		for i,v in ipairs(value["start_point"]) do
			if type(v) == "table" then
				interaction.mStartPoint[i-1] = CCPointMake(v[1],v[2])
				interaction.mStartPointCount = interaction.mStartPointCount + 1
			end
		end
	end
	
	if value["script"] ~= nil and type(value["script"]) == "string" then
		interaction.mScript = value["script"]
	end

	if value["duration"] ~= nil and type(value["duration"]) == "number" then
		interaction.mDuration = value["duration"]
	end

	if value["times"] ~= nil and type(value["times"]) == "number" then
		interaction.mTimes = value["times"]
	end
	
	if value["character_animation"] ~= nil and type(value["character_animation"]) == "string" then
		interaction.mCharacterAnimation = value["character_animation"]
	end
	
	if value["animation"] ~= nil and type(value["animation"]) == "string" then
		interaction.mAnimation = value["animation"]
	end

	if value["animation_reverse"] ~= nil and type(value["animation_reverse"]) == "boolean" then
		interaction.mAnimationReverse = value["animation_reverse"]
	end
	
	if value["animation_end"] ~= nil and type(value["animation_end"]) == "string" then
		interaction.mAnimationEnd = value["animation_end"]
	end

	if value["animation_end_reverse"] ~= nil and type(value["animation_end_reverse"]) == "boolean" then
		interaction.mAnimationEndReverse = value["animation_end_reverse"]
	end
	
	if value["sound"] ~= nil and type(value["sound"]) == "string" then
		interaction.mSound = value["sound"]
	end
	
	if value["sound_end"] ~= nil and type(value["sound_end"]) == "string" then
		interaction.mSoundEnd = value["sound_end"]
	end
	
	if value["sprite"] ~= nil and type(value["sprite"]) == "string" then
		interaction.mSprite = value["sprite"]
	end
	
	if value["sprite_end"] ~= nil and type(value["sprite_end"]) == "string" then
		interaction.mSpriteEnd = value["sprite_end"]
	end

	if value["interaction_end_sprite_removed"] ~= nil and type(value["interaction_end_sprite_removed"]) == "boolean" then
		interaction.mRemoveSpriteAfterInteraction = value["interaction_end_sprite_removed"]
	end
	
	if value["requirement_character_type"] ~= nil and type(value["requirement_character_type"]) == "string" then
		interaction.mRequirementCharacterType = value["requirement_character_type"]
	end

	if value["requirement_character_level"] ~= nil and type(value["requirement_character_level"]) == "number" then
		interaction.mRequirementCharacterLevel = value["requirement_character_level"]
	end

	if value["requirement_item"] ~= nil and type(value["requirement_item"]) == "number" then
		interaction.mRequirementItem = value["requirement_item"]
	end

	if value["cost"] ~= nil and type(value["cost"]) == "number" then
		interaction.mCost = value["cost"]
	end

	if value["reset_trigger"] ~= nil and type(value["reset_trigger"]) == "boolean" then
		interaction.mResetTrigger = value["reset_trigger"]
	end
	
	return interaction
end

function getDefault(name)
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tiledMap = gameScreen:getTiledMap()
		if tiledMap ~= nil then
			local interactionManager = tiledMap:getInteractionManager()
			if interactionManager ~= nil then
				return interactionManager:getInteraction(name)
			end
		end
	end
	return nil
end
