
module("LevelSystem", package.seeall)

-- avoid memory leak
collectgarbage("setpause", 100)
collectgarbage("setstepmul", 5000)

function getLevelObject(name)
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			return tileMap:getLevelObject(name)
		end
	end
	return nil
end

function getObjectLocation(name)
	local object = getLevelObject(name)
	if object ~= nil then
		local location = object:getLocation()
		return math.floor(location.x+0.1), math.floor(location.y+0.1)
	end
	return -1, -1
end

function interaction(trigger, interaction, reset)
	if trigger == nil then
		return
	end
	local object = getLevelObject(trigger:getName())
	if object ~= nil then
		object:startInteraction(interaction, reset, trigger:getType())
	end
end

function enable(name)
	local object = getLevelObject(name)
	if object ~= nil then
		object:setEnable(true)
	end
end

function disable(name)
	local object = getLevelObject(name)
	if object ~= nil then
		object:setEnable(false)
	end
end
