
require("InteractionSystem")
require("LevelSystem")
require("FogSystem")
require("MindBubble")

-- global variable
gFontLabel = nil

-- x,y: 0.0-1.0
local function showLabelWithRelativePos(text, x, y)
	if gFontLabel == nil then
--		gFontLabel = CCLabelTTF:labelWithString("", "Arial", 20)
--		local winSize = CCDirector:sharedDirector():getWinSize()
--		gFontLabel:setPosition(CCPoint(winSize.width * x, winSize.height * y))
--		CCDirector:sharedDirector():getRunningScene():addChild(gFontLabel)

		local gameScreen = GameScreen:getCurrentGameScreen()
		if gameScreen == nil then
			return
		end

		local labelSize = CCSizeMake(CCDirector:sharedDirector():getWinSize().width * 0.8, 200.0);
		gFontLabel = CCLabelTTF:labelWithString("", labelSize, 0, "Arial", 20)
		
		local winSize = CCDirector:sharedDirector():getWinSize()
		gFontLabel:setPositionX(winSize.width * x)
		gFontLabel:setPositionY(winSize.height * y)
		gameScreen:addChild(gFontLabel, 1000)
	end
	gFontLabel:setString(text)
end

-- triggers functions

function func1(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			local dwarf2 = tileMap:getCharacter("Dwarf2")
			if dwarf2 ~= nil then
				local posDwarf2 = dwarf2:getLocation()
				gameScreen:moveCharacterToTileByName("Dwarf1", posDwarf2, false)
			end
			gameScreen:moveCharacterToTileByName("Dwarf2", CCPointMake(45,48), false)
		end
	end
end

function testIdleAnim(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	print("disable Zombie1")
	LevelSystem.getLevelObject("Zombie1"):setEnable(false)
end

function func_trigger_visit_1(trigger, state, isEnabled)
	if isEnabled == 1 or state == TriggerOnLeave then
		return
	end
--	local x,y = LevelSystem.getObjectLocation("Zombie1")
--	showLabelWithRelativePos("Zombie1: " .. tostring(x) .. ", " .. tostring(y), 0.5, 0.5)
	--ActiveQuestManager:sharedManager():receiveQuest("1_5_speak_golem")
--	LevelSystem.getLevelObject("Zombie1"):setEnable(true)
end

function func_trigger_visit_2(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end

	ActiveQuestManager:sharedManager():completeQuest("1_5_speak_golem")
	
--[[	
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			local selCharacter = tileMap:getSelectedCharacter()
			if selCharacter ~= nil then
				selCharacter:stopMoving()
				selCharacter:setLocation(CCPointMake(53,64))
			end
		end
	end]]--
end

function func4(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local intr = {
		["start_point"] = {{49,61},{49,62},{48,62},{47,62},{47,61}},
		["script"] = "scripts/zombie1.lua",
		["duration"] = 2.0,
		["animation"] = "",
		["animation_end"] = "",
		["sound"] = "sounds/effect1.wav",
		["sound_end"] = "sounds/notify.wav",
		["interaction_end_sprite_removed"] = true,
	}
	LevelSystem.interaction(trigger, InteractionSystem.get(intr), false)
end

function func5(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local intr = {
		["start_point"] = {{50,56},{50,58}},
		["script"] = "scripts/gate1.lua",
		["duration"] = 6.0,
		["animation"] = "gate1_open",
		["animation_end"] = "gate1_open",
		["animation_end_reverse"] = true,
		["sound"] = "sounds/effect1.wav",
		["sound_end"] = "sounds/effect1.wav",
	}
	LevelSystem.interaction(trigger, InteractionSystem.get(intr), true)
end

function func6(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local intr = {
		["start_point"] = {{52,63}},
		["script"] = "scripts/chest1.lua",
		["duration"] = 2.0,
		["animation"] = "",
		["animation_end"] = "gate1_open",
		["animation_end_reverse"] = false,
		["sound"] = "sounds/default.wav",
		["sound_end"] = "sounds/effect1.wav",
	}
	LevelSystem.interaction(trigger, InteractionSystem.get(intr), true)
end

function testTroll(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local intr = {
		["start_point"] = {{41,44}},
		["script"] = "scripts/zombie1.lua",
		["duration"] = 2.0,
		["animation"] = "",
		["animation_end"] = "",
		["sound"] = "sounds/effect1.wav",
		["sound_end"] = "sounds/notify.wav",
		["interaction_end_sprite_removed"] = true,
	}
	LevelSystem.interaction(trigger, InteractionSystem.get(intr), false)
end

function testClown(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local intr = {
		["start_point"] = {{45,46}},
		["script"] = "scripts/zombie1.lua",
		["duration"] = 2.0,
		["animation"] = "",
		["animation_end"] = "",
		["sound"] = "sounds/effect1.wav",
		["sound_end"] = "sounds/notify.wav",
		["interaction_end_sprite_removed"] = true,
	}
	LevelSystem.interaction(trigger, InteractionSystem.get(intr), false)
end

function func_platform2_point1(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			local selCharacter = tileMap:getSelectedCharacter()
			if selCharacter ~= nil then
			end
		end
	end
end

function func_platform2_point2(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			local selCharacter = tileMap:getSelectedCharacter()
			if selCharacter ~= nil then
			end
		end
	end
end


function fog1(trigger, state, isEnabled)
	if isEnabled == 1 or state == TriggerOnLeave then
		return
	end
	FogSystem.visit("fog1")
end

function fog2(trigger, state, isEnabled)
	if isEnabled == 1 or state == TriggerOnLeave then
		return
	end
	FogSystem.visit("fog2")
end

function fog3(trigger, state, isEnabled)
	if isEnabled == 1 or state == TriggerOnLeave then
		return
	end
	FogSystem.visit("fog3")
end
