
module("TriggerSystem", package.seeall)

-- avoid memory leak
collectgarbage("setpause", 100)
collectgarbage("setstepmul", 5000)

local cclog = function(...)
    print(string.format(...))
end

require("LevelSystem")
require("InteractionSystem")

function getTrigger(name)
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen ~= nil then
		local tiledMap = gameScreen:getTiledMap()
		if tiledMap ~= nil then
			local triggerManager = tiledMap:getTriggerManager()
			if triggerManager ~= nil then
				return triggerManager:getTrigger(name)
			end
		end
	end
	return nil
end

-- Register script handler for the TriggerManager
function registerScriptHandler(funcEvent)
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen then
		local tiledMap = gameScreen:getTiledMap()
		if tiledMap then
			local triggerManager = tiledMap:getTriggerManager()
			if triggerManager then
				triggerManager:registerScriptHandler(funcEvent)
			end
		end
	end
end

function default_trigger_func(trigger, state, isEnabled)
	if isEnabled == 1 then
		return
	end
	if state == TriggerOnLeave then
		return
	end
	LevelSystem.interaction(trigger, InteractionSystem.getDefault(trigger:getName()), false)
end

function init(triggers)
	local triggerEvent = function(object, state, isEnabled)
		if object == nil then
			return
		end
		local triggerName = object:getName()
		local func = triggers[triggerName]
		if func ~= nil and type(func) == "function" then
			func(object, state, isEnabled)
		else
			default_trigger_func(object, state, isEnabled)
		end
	end
	registerScriptHandler(triggerEvent)
end
