
module("WalkableMap", package.seeall)

-- avoid memory leak
collectgarbage("setpause", 100)
collectgarbage("setstepmul", 5000)

local cclog = function(...)
    print(string.format(...))
end

function getLevelObject(name)
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			return tileMap:getLevelObject(name)
		end
	end
	return nil
end

function getWalkableMap()
	local gameScreen = GameScreen:getCurrentGameScreen()
	if gameScreen then
		local tileMap = gameScreen:getTiledMap()
		if tileMap ~= nil then
			return tileMap:getWalkableMap()
		end
	end
	return nil
end

function lockSingle(tile)
	local walkableMap = getWalkableMap()
	if walkableMap ~= nil then
		walkableMap:lockTile(tile)
	end
end

function lock(value)
	local walkableMap = getWalkableMap()
	if walkableMap ~= nil then
		if type(value) == "userdata" then
			walkableMap:lockTile(value)
		elseif type(value) == "table" then
			if type(value[1]) == "number" then
				walkableMap:lockTile(CCPointMake(value[1],value[2]))
			else
				for i,v in ipairs(value) do
					if type(v) == "userdata" then
						walkableMap:lockTile(v)
					elseif type(v) == "table" then
						walkableMap:lockTile(CCPointMake(v[1],v[2]))
					end
				end
			end
		end
	end
end

function unlockSingle(tile)
	local walkableMap = getWalkableMap()
	if walkableMap ~= nil then
		walkableMap:unlockTile(tile)
	end
end

function unlock(value)
	local walkableMap = getWalkableMap()
	if walkableMap ~= nil then
		if type(value) == "userdata" then
			walkableMap:unlockTile(value)
		elseif type(value) == "table" then
			if type(value[1]) == "number" then
				walkableMap:unlockTile(CCPointMake(value[1],value[2]))
			else
				for i,v in ipairs(value) do
					if type(v) == "userdata" then
						walkableMap:unlockTile(v)
					elseif type(v) == "table" then
						walkableMap:unlockTile(CCPointMake(v[1],v[2]))
					end
				end
			end
		end
	end
end

function changeStateSingle(tile, name)
	local levelObject = getLevelObject(name)
	if levelObject ~= nil then
		local state = levelObject:getState()
		if state == 3 then -- LO_STATE_START_FIRST_PHASE
			unlock(tile)
		else
			lock(tile)
		end
	end
end

function changeState(value, name)
	local walkableMap = getWalkableMap()
	if walkableMap ~= nil then
		if type(value) == "userdata" then
			changeStateSingle(value, name)
		elseif type(value) == "table" then
			if type(value[1]) == "number" then
				changeStateSingle(CCPointMake(value[1],value[2]), name)
			else
				for i,v in ipairs(value) do
					if type(v) == "userdata" then
						changeStateSingle(v, name)
					elseif type(v) == "table" then
						changeStateSingle(CCPointMake(v[1],v[2]), name)
					end
				end
			end
		end
	end
end
